Documentation
¶
Overview ¶
Package generator contains builders used for page conversion (example HTML to PDF).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Generator ¶
type Generator interface {
// GenerateFile converts a rod Page instance to a file.
GenerateFile(page *rod.Page) ([]byte, error)
// SetFullPage sets the pages to be converted. If false, only the first page is selected.
SetFullPage(fullPage bool) Generator
}
Generator interface contains the methods used for page conversion.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package jpeg implements the builder for JPEG files.
|
Package jpeg implements the builder for JPEG files. |
|
Package pdf implements the builder for PDF files.
|
Package pdf implements the builder for PDF files. |
|
Package png implements the builder for PNG files.
|
Package png implements the builder for PNG files. |
Click to show internal directories.
Click to hide internal directories.