Documentation
¶
Overview ¶
Package webdriver provides a wrapper for the rod library to perform browser operations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WebDriver ¶
type WebDriver struct {
// Browser is a rod Browser instance.
Browser *rod.Browser
// LoadTimeout controlls max page load time before context is canceled.
LoadTimeout time.Duration
// PageIdleTime sets the wait time after the page stops receiving requests.
PageIdleTime time.Duration
}
WebDriver is a wrapper of the rod library.
func FromConfig ¶
func FromConfig(config *WebDriverConfig) *WebDriver
func FromDefault ¶
func FromDefault() *WebDriver
func (*WebDriver) HTMLToPage ¶
HTMLToPage converts the binary html to a rod Page instance.
Click to show internal directories.
Click to hide internal directories.