Documentation
¶
Overview ¶
Package rod contains go-rod implementation. It implements some metho
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Rod ¶
type Rod struct {
// Browser is a rod Browser instance.
Browser *rod.Browser
// LoadTimeout controlls max page load time before context is canceled.
LoadTimeout time.Duration
// PageIdleTime sets the wait time after the page stops receiving requests.
PageIdleTime time.Duration
}
Rod is responsible for browsser operations.
func (*Rod) ByteToPage ¶
ByteToPage converts the binary to a rod Page instance.
Click to show internal directories.
Click to hide internal directories.